@@ -17,6 +17,7 @@
 """A Git Repository that keeps a Debian Package"""
 
 import re
+from gbp.command_wrappers import CommandExecFailed
 from gbp.git import GitRepository, GitRepositoryError
 from gbp.deb.pristinetar import DebianPristineTar
 from gbp.format import format_str
@@ -282,7 +283,7 @@ class DebianGitRepository(GitRepository):
     def create_pristinetar_commits(self, upstream_tree, tarball, component_tarballs):
         """
         Create pristine-tar commits for a package with main tarball tarball
-        and (optionl) component tarballs based on upstream_tree
+        and (optional) component tarballs based on upstream_tree
 
         @param tarball: path to main tarball
         @param component_tarballs: C{list} of C{tuple}s of component
@@ -292,12 +293,15 @@ class DebianGitRepository(GitRepository):
         components = [c for (c, t) in component_tarballs]
         main_tree = self.tree_drop_dirs(upstream_tree, components)
 
-        for component, name in component_tarballs:
-            subtree = self.tree_get_dir(upstream_tree, component)
-            if not subtree:
-                raise GitRepositoryError("No tree for '%s' found in '%s' to create pristine tar commit from" % (component, upstream_tree))
-            gbp.log.debug("Creating pristine tar commit '%s' from '%s'" % (component, subtree))
-            self.pristine_tar.commit(name, subtree)
-        self.pristine_tar.commit(tarball, main_tree)
+        try:
+            for component, name in component_tarballs:
+                subtree = self.tree_get_dir(upstream_tree, component)
+                if not subtree:
+                    raise GitRepositoryError("No tree for '%s' found in '%s' to create pristine tar commit from" % (component, upstream_tree))
+                gbp.log.debug("Creating pristine tar commit '%s' from '%s'" % (component, subtree))
+                self.pristine_tar.commit(name, subtree, quiet=True)
+            self.pristine_tar.commit(tarball, main_tree, quiet=True)
+        except CommandExecFailed as e:
+            raise GitRepositoryError(str(e))
 
 # vim:et:ts=4:sw=4:et:sts=4:ai:set list listchars=tab\:»·,trail\:·:
