@@ -109,9 +109,8 @@ def print_cmd_values(query, printer):
         return print_all_options(parser, printer)
 
 
-def value_printer(value):
-    if (value):
-        print(value)
+def value_printer(output):
+    print(output)
 
 
 def main(argv):
@@ -125,10 +124,10 @@ def main(argv):
     gbp.log.setup(options.color, options.verbose, options.color_scheme)
 
     if not args:
-        gbp.log.error("No command given")
+        gbp.log.err("No command given")
         return 2
     elif len(args) != 2:
-        gbp.log.error("Can only take a command or command.optionname, check --help")
+        gbp.log.err("Can only take a command or command.optionname, check --help")
         return 2
     else:
         query = args[1]
@@ -136,6 +135,7 @@ def main(argv):
     retval = print_cmd_values(query, value_printer)
     return retval
 
+
 if __name__ == '__main__':
     sys.exit(main(sys.argv))
 
